@@ -31,14 +31,24 @@ var searchData=
   ['wxarchiveoutputstream',['wxArchiveOutputStream',['../classwx_archive_output_stream.html',1,'']]],
   ['wxarray_3c_20t_20_3e',['wxArray&lt; T &gt;',['../classwx_array_3_01_t_01_4.html',1,'']]],
   ['wxarraystring',['wxArrayString',['../classwx_array_string.html',1,'']]],
+  ['wxarraystringproperty',['wxArrayStringProperty',['../classwx_array_string_property.html',1,'']]],
   ['wxartprovider',['wxArtProvider',['../classwx_art_provider.html',1,'']]],
+  ['wxauidefaultdockart',['wxAuiDefaultDockArt',['../classwx_aui_default_dock_art.html',1,'']]],
   ['wxauidefaulttabart',['wxAuiDefaultTabArt',['../classwx_aui_default_tab_art.html',1,'']]],
   ['wxauidefaulttoolbarart',['wxAuiDefaultToolBarArt',['../classwx_aui_default_tool_bar_art.html',1,'']]],
   ['wxauidockart',['wxAuiDockArt',['../classwx_aui_dock_art.html',1,'']]],
+  ['wxauidockinfo',['wxAuiDockInfo',['../classwx_aui_dock_info.html',1,'']]],
+  ['wxauidockuipart',['wxAuiDockUIPart',['../classwx_aui_dock_u_i_part.html',1,'']]],
+  ['wxauifloatingframe',['wxAuiFloatingFrame',['../classwx_aui_floating_frame.html',1,'']]],
   ['wxauimanager',['wxAuiManager',['../classwx_aui_manager.html',1,'']]],
   ['wxauimanagerevent',['wxAuiManagerEvent',['../classwx_aui_manager_event.html',1,'']]],
+  ['wxauimdichildframe',['wxAuiMDIChildFrame',['../classwx_aui_m_d_i_child_frame.html',1,'']]],
+  ['wxauimdiclientwindow',['wxAuiMDIClientWindow',['../classwx_aui_m_d_i_client_window.html',1,'']]],
+  ['wxauimdiparentframe',['wxAuiMDIParentFrame',['../classwx_aui_m_d_i_parent_frame.html',1,'']]],
   ['wxauinotebook',['wxAuiNotebook',['../classwx_aui_notebook.html',1,'']]],
   ['wxauinotebookevent',['wxAuiNotebookEvent',['../classwx_aui_notebook_event.html',1,'']]],
+  ['wxauinotebookpage',['wxAuiNotebookPage',['../classwx_aui_notebook_page.html',1,'']]],
+  ['wxauipanebutton',['wxAuiPaneButton',['../classwx_aui_pane_button.html',1,'']]],
   ['wxauipaneinfo',['wxAuiPaneInfo',['../classwx_aui_pane_info.html',1,'']]],
   ['wxauisimpletabart',['wxAuiSimpleTabArt',['../classwx_aui_simple_tab_art.html',1,'']]],
   ['wxauitabart',['wxAuiTabArt',['../classwx_aui_tab_art.html',1,'']]],
@@ -59,6 +69,7 @@ var searchData=
   ['wxbitmaptogglebutton',['wxBitmapToggleButton',['../classwx_bitmap_toggle_button.html',1,'']]],
   ['wxbookctrlbase',['wxBookCtrlBase',['../classwx_book_ctrl_base.html',1,'']]],
   ['wxbookctrlevent',['wxBookCtrlEvent',['../classwx_book_ctrl_event.html',1,'']]],
+  ['wxboolproperty',['wxBoolProperty',['../classwx_bool_property.html',1,'']]],
   ['wxboxsizer',['wxBoxSizer',['../classwx_box_sizer.html',1,'']]],
   ['wxbrush',['wxBrush',['../classwx_brush.html',1,'']]],
   ['wxbrushlist',['wxBrushList',['../classwx_brush_list.html',1,'']]],
@@ -105,6 +116,8 @@ var searchData=
   ['wxcolourdialog',['wxColourDialog',['../classwx_colour_dialog.html',1,'']]],
   ['wxcolourpickerctrl',['wxColourPickerCtrl',['../classwx_colour_picker_ctrl.html',1,'']]],
   ['wxcolourpickerevent',['wxColourPickerEvent',['../classwx_colour_picker_event.html',1,'']]],
+  ['wxcolourproperty',['wxColourProperty',['../classwx_colour_property.html',1,'']]],
+  ['wxcolourpropertyvalue',['wxColourPropertyValue',['../classwx_colour_property_value.html',1,'']]],
   ['wxcombobox',['wxComboBox',['../classwx_combo_box.html',1,'']]],
   ['wxcomboctrl',['wxComboCtrl',['../classwx_combo_ctrl.html',1,'']]],
   ['wxcomboctrlfeatures',['wxComboCtrlFeatures',['../structwx_combo_ctrl_features.html',1,'']]],
@@ -129,6 +142,7 @@ var searchData=
   ['wxcriticalsectionlocker',['wxCriticalSectionLocker',['../classwx_critical_section_locker.html',1,'']]],
   ['wxcsconv',['wxCSConv',['../classwx_c_s_conv.html',1,'']]],
   ['wxcursor',['wxCursor',['../classwx_cursor.html',1,'']]],
+  ['wxcursorproperty',['wxCursorProperty',['../classwx_cursor_property.html',1,'']]],
   ['wxcustombackgroundwindow',['wxCustomBackgroundWindow',['../classwx_custom_background_window.html',1,'']]],
   ['wxcustomdataobject',['wxCustomDataObject',['../classwx_custom_data_object.html',1,'']]],
   ['wxdataformat',['wxDataFormat',['../classwx_data_format.html',1,'']]],
@@ -139,6 +153,7 @@ var searchData=
   ['wxdataobjectsimple',['wxDataObjectSimple',['../classwx_data_object_simple.html',1,'']]],
   ['wxdataoutputstream',['wxDataOutputStream',['../classwx_data_output_stream.html',1,'']]],
   ['wxdataviewbitmaprenderer',['wxDataViewBitmapRenderer',['../classwx_data_view_bitmap_renderer.html',1,'']]],
+  ['wxdataviewcheckicontextrenderer',['wxDataViewCheckIconTextRenderer',['../classwx_data_view_check_icon_text_renderer.html',1,'']]],
   ['wxdataviewchoicebyindexrenderer',['wxDataViewChoiceByIndexRenderer',['../classwx_data_view_choice_by_index_renderer.html',1,'']]],
   ['wxdataviewchoicerenderer',['wxDataViewChoiceRenderer',['../classwx_data_view_choice_renderer.html',1,'']]],
   ['wxdataviewcolumn',['wxDataViewColumn',['../classwx_data_view_column.html',1,'']]],
@@ -163,9 +178,11 @@ var searchData=
   ['wxdataviewtogglerenderer',['wxDataViewToggleRenderer',['../classwx_data_view_toggle_renderer.html',1,'']]],
   ['wxdataviewtreectrl',['wxDataViewTreeCtrl',['../classwx_data_view_tree_ctrl.html',1,'']]],
   ['wxdataviewtreestore',['wxDataViewTreeStore',['../classwx_data_view_tree_store.html',1,'']]],
+  ['wxdataviewvalueadjuster',['wxDataViewValueAdjuster',['../classwx_data_view_value_adjuster.html',1,'']]],
   ['wxdataviewvirtuallistmodel',['wxDataViewVirtualListModel',['../classwx_data_view_virtual_list_model.html',1,'']]],
   ['wxdateevent',['wxDateEvent',['../classwx_date_event.html',1,'']]],
   ['wxdatepickerctrl',['wxDatePickerCtrl',['../classwx_date_picker_ctrl.html',1,'']]],
+  ['wxdateproperty',['wxDateProperty',['../classwx_date_property.html',1,'']]],
   ['wxdatespan',['wxDateSpan',['../classwx_date_span.html',1,'']]],
   ['wxdatetime',['wxDateTime',['../classwx_date_time.html',1,'']]],
   ['wxdatetimeholidayauthority',['wxDateTimeHolidayAuthority',['../classwx_date_time_holiday_authority.html',1,'']]],
@@ -195,6 +212,7 @@ var searchData=
   ['wxdirdialog',['wxDirDialog',['../classwx_dir_dialog.html',1,'']]],
   ['wxdirfilterlistctrl',['wxDirFilterListCtrl',['../classwx_dir_filter_list_ctrl.html',1,'']]],
   ['wxdirpickerctrl',['wxDirPickerCtrl',['../classwx_dir_picker_ctrl.html',1,'']]],
+  ['wxdirproperty',['wxDirProperty',['../classwx_dir_property.html',1,'']]],
   ['wxdirtraverser',['wxDirTraverser',['../classwx_dir_traverser.html',1,'']]],
   ['wxdisplay',['wxDisplay',['../classwx_display.html',1,'']]],
   ['wxdisplaychangedevent',['wxDisplayChangedEvent',['../classwx_display_changed_event.html',1,'']]],
@@ -212,7 +230,9 @@ var searchData=
   ['wxdynamiclibrary',['wxDynamicLibrary',['../classwx_dynamic_library.html',1,'']]],
   ['wxdynamiclibrarydetails',['wxDynamicLibraryDetails',['../classwx_dynamic_library_details.html',1,'']]],
   ['wxeditablelistbox',['wxEditableListBox',['../classwx_editable_list_box.html',1,'']]],
+  ['wxeditenumproperty',['wxEditEnumProperty',['../classwx_edit_enum_property.html',1,'']]],
   ['wxencodingconverter',['wxEncodingConverter',['../classwx_encoding_converter.html',1,'']]],
+  ['wxenumproperty',['wxEnumProperty',['../classwx_enum_property.html',1,'']]],
   ['wxeraseevent',['wxEraseEvent',['../classwx_erase_event.html',1,'']]],
   ['wxevent',['wxEvent',['../classwx_event.html',1,'']]],
   ['wxeventblocker',['wxEventBlocker',['../classwx_event_blocker.html',1,'']]],
@@ -239,6 +259,7 @@ var searchData=
   ['wxfilename',['wxFileName',['../classwx_file_name.html',1,'']]],
   ['wxfileoutputstream',['wxFileOutputStream',['../classwx_file_output_stream.html',1,'']]],
   ['wxfilepickerctrl',['wxFilePickerCtrl',['../classwx_file_picker_ctrl.html',1,'']]],
+  ['wxfileproperty',['wxFileProperty',['../classwx_file_property.html',1,'']]],
   ['wxfilestream',['wxFileStream',['../classwx_file_stream.html',1,'']]],
   ['wxfilesystem',['wxFileSystem',['../classwx_file_system.html',1,'']]],
   ['wxfilesystemhandler',['wxFileSystemHandler',['../classwx_file_system_handler.html',1,'']]],
@@ -254,8 +275,10 @@ var searchData=
   ['wxfinddialogevent',['wxFindDialogEvent',['../classwx_find_dialog_event.html',1,'']]],
   ['wxfindreplacedata',['wxFindReplaceData',['../classwx_find_replace_data.html',1,'']]],
   ['wxfindreplacedialog',['wxFindReplaceDialog',['../classwx_find_replace_dialog.html',1,'']]],
+  ['wxflagsproperty',['wxFlagsProperty',['../classwx_flags_property.html',1,'']]],
   ['wxflexgridsizer',['wxFlexGridSizer',['../classwx_flex_grid_sizer.html',1,'']]],
   ['wxfloatingpointvalidator',['wxFloatingPointValidator',['../classwx_floating_point_validator.html',1,'']]],
+  ['wxfloatproperty',['wxFloatProperty',['../classwx_float_property.html',1,'']]],
   ['wxfocusevent',['wxFocusEvent',['../classwx_focus_event.html',1,'']]],
   ['wxfont',['wxFont',['../classwx_font.html',1,'']]],
   ['wxfontdata',['wxFontData',['../classwx_font_data.html',1,'']]],
@@ -267,6 +290,7 @@ var searchData=
   ['wxfontmetrics',['wxFontMetrics',['../structwx_font_metrics.html',1,'']]],
   ['wxfontpickerctrl',['wxFontPickerCtrl',['../classwx_font_picker_ctrl.html',1,'']]],
   ['wxfontpickerevent',['wxFontPickerEvent',['../classwx_font_picker_event.html',1,'']]],
+  ['wxfontproperty',['wxFontProperty',['../classwx_font_property.html',1,'']]],
   ['wxframe',['wxFrame',['../classwx_frame.html',1,'']]],
   ['wxfsfile',['wxFSFile',['../classwx_f_s_file.html',1,'']]],
   ['wxfsinputstream',['wxFSInputStream',['../classwx_f_s_input_stream.html',1,'']]],
@@ -282,6 +306,8 @@ var searchData=
   ['wxgenericdirctrl',['wxGenericDirCtrl',['../classwx_generic_dir_ctrl.html',1,'']]],
   ['wxgenericprogressdialog',['wxGenericProgressDialog',['../classwx_generic_progress_dialog.html',1,'']]],
   ['wxgenericvalidator',['wxGenericValidator',['../classwx_generic_validator.html',1,'']]],
+  ['wxgestureevent',['wxGestureEvent',['../classwx_gesture_event.html',1,'']]],
+  ['wxgifhandler',['wxGIFHandler',['../classwx_g_i_f_handler.html',1,'']]],
   ['wxglattribsbase',['wxGLAttribsBase',['../classwx_g_l_attribs_base.html',1,'']]],
   ['wxglattributes',['wxGLAttributes',['../classwx_g_l_attributes.html',1,'']]],
   ['wxglcanvas',['wxGLCanvas',['../classwx_g_l_canvas.html',1,'']]],
@@ -297,6 +323,7 @@ var searchData=
   ['wxgraphicsobject',['wxGraphicsObject',['../classwx_graphics_object.html',1,'']]],
   ['wxgraphicspath',['wxGraphicsPath',['../classwx_graphics_path.html',1,'']]],
   ['wxgraphicspen',['wxGraphicsPen',['../classwx_graphics_pen.html',1,'']]],
+  ['wxgraphicspeninfo',['wxGraphicsPenInfo',['../classwx_graphics_pen_info.html',1,'']]],
   ['wxgraphicsrenderer',['wxGraphicsRenderer',['../classwx_graphics_renderer.html',1,'']]],
   ['wxgrid',['wxGrid',['../classwx_grid.html',1,'']]],
   ['wxgridbagsizer',['wxGridBagSizer',['../classwx_grid_bag_sizer.html',1,'']]],
@@ -398,7 +425,9 @@ var searchData=
   ['wxiconlocation',['wxIconLocation',['../classwx_icon_location.html',1,'']]],
   ['wxidleevent',['wxIdleEvent',['../classwx_idle_event.html',1,'']]],
   ['wxidmanager',['wxIdManager',['../classwx_id_manager.html',1,'']]],
+  ['wxiffhandler',['wxIFFHandler',['../classwx_i_f_f_handler.html',1,'']]],
   ['wximage',['wxImage',['../classwx_image.html',1,'']]],
+  ['wximagefileproperty',['wxImageFileProperty',['../classwx_image_file_property.html',1,'']]],
   ['wximagehandler',['wxImageHandler',['../classwx_image_handler.html',1,'']]],
   ['wximagehistogram',['wxImageHistogram',['../classwx_image_histogram.html',1,'']]],
   ['wximagelist',['wxImageList',['../classwx_image_list.html',1,'']]],
@@ -409,12 +438,15 @@ var searchData=
   ['wxinputstream',['wxInputStream',['../classwx_input_stream.html',1,'']]],
   ['wxintegervalidator',['wxIntegerValidator',['../classwx_integer_validator.html',1,'']]],
   ['wxinternetfshandler',['wxInternetFSHandler',['../classwx_internet_f_s_handler.html',1,'']]],
+  ['wxintproperty',['wxIntProperty',['../classwx_int_property.html',1,'']]],
   ['wxipaddress',['wxIPaddress',['../classwx_i_paddress.html',1,'']]],
   ['wxipv4address',['wxIPV4address',['../classwx_i_p_v4address.html',1,'']]],
+  ['wxitemattr',['wxItemAttr',['../classwx_item_attr.html',1,'']]],
   ['wxitemcontainer',['wxItemContainer',['../classwx_item_container.html',1,'']]],
   ['wxitemcontainerimmutable',['wxItemContainerImmutable',['../classwx_item_container_immutable.html',1,'']]],
   ['wxjoystick',['wxJoystick',['../classwx_joystick.html',1,'']]],
   ['wxjoystickevent',['wxJoystickEvent',['../classwx_joystick_event.html',1,'']]],
+  ['wxjpeghandler',['wxJPEGHandler',['../classwx_j_p_e_g_handler.html',1,'']]],
   ['wxkeyboardstate',['wxKeyboardState',['../classwx_keyboard_state.html',1,'']]],
   ['wxkeyevent',['wxKeyEvent',['../classwx_key_event.html',1,'']]],
   ['wxlanguageinfo',['wxLanguageInfo',['../structwx_language_info.html',1,'']]],
@@ -427,7 +459,6 @@ var searchData=
   ['wxlistctrl',['wxListCtrl',['../classwx_list_ctrl.html',1,'']]],
   ['wxlistevent',['wxListEvent',['../classwx_list_event.html',1,'']]],
   ['wxlistitem',['wxListItem',['../classwx_list_item.html',1,'']]],
-  ['wxlistitemattr',['wxListItemAttr',['../classwx_list_item_attr.html',1,'']]],
   ['wxlistview',['wxListView',['../classwx_list_view.html',1,'']]],
   ['wxlocale',['wxLocale',['../classwx_locale.html',1,'']]],
   ['wxlog',['wxLog',['../classwx_log.html',1,'']]],
@@ -444,6 +475,8 @@ var searchData=
   ['wxlogtextctrl',['wxLogTextCtrl',['../classwx_log_text_ctrl.html',1,'']]],
   ['wxlogwindow',['wxLogWindow',['../classwx_log_window.html',1,'']]],
   ['wxlonglong',['wxLongLong',['../classwx_long_long.html',1,'']]],
+  ['wxlongpressevent',['wxLongPressEvent',['../classwx_long_press_event.html',1,'']]],
+  ['wxlongstringproperty',['wxLongStringProperty',['../classwx_long_string_property.html',1,'']]],
   ['wxmask',['wxMask',['../classwx_mask.html',1,'']]],
   ['wxmatrix2d',['wxMatrix2D',['../structwx_matrix2_d.html',1,'']]],
   ['wxmaximizeevent',['wxMaximizeEvent',['../classwx_maximize_event.html',1,'']]],
@@ -488,6 +521,7 @@ var searchData=
   ['wxmoveevent',['wxMoveEvent',['../classwx_move_event.html',1,'']]],
   ['wxmsgcatalog',['wxMsgCatalog',['../classwx_msg_catalog.html',1,'']]],
   ['wxmultichoicedialog',['wxMultiChoiceDialog',['../classwx_multi_choice_dialog.html',1,'']]],
+  ['wxmultichoiceproperty',['wxMultiChoiceProperty',['../classwx_multi_choice_property.html',1,'']]],
   ['wxmutex',['wxMutex',['../classwx_mutex.html',1,'']]],
   ['wxmutexlocker',['wxMutexLocker',['../classwx_mutex_locker.html',1,'']]],
   ['wxnativefontinfo',['wxNativeFontInfo',['../classwx_native_font_info.html',1,'']]],
@@ -500,6 +534,7 @@ var searchData=
   ['wxnotificationmessage',['wxNotificationMessage',['../classwx_notification_message.html',1,'']]],
   ['wxnotifyevent',['wxNotifyEvent',['../classwx_notify_event.html',1,'']]],
   ['wxnumberformatter',['wxNumberFormatter',['../classwx_number_formatter.html',1,'']]],
+  ['wxnumericpropertyvalidator',['wxNumericPropertyValidator',['../classwx_numeric_property_validator.html',1,'']]],
   ['wxnumvalidator',['wxNumValidator',['../classwx_num_validator.html',1,'']]],
   ['wxobject',['wxObject',['../classwx_object.html',1,'']]],
   ['wxobjectdataptr_3c_20t_20_3e',['wxObjectDataPtr&lt; T &gt;',['../classwx_object_data_ptr_3_01_t_01_4.html',1,'']]],
@@ -514,28 +549,58 @@ var searchData=
   ['wxpalette',['wxPalette',['../classwx_palette.html',1,'']]],
   ['wxpalettechangedevent',['wxPaletteChangedEvent',['../classwx_palette_changed_event.html',1,'']]],
   ['wxpanel',['wxPanel',['../classwx_panel.html',1,'']]],
+  ['wxpangestureevent',['wxPanGestureEvent',['../classwx_pan_gesture_event.html',1,'']]],
   ['wxpasswordentrydialog',['wxPasswordEntryDialog',['../classwx_password_entry_dialog.html',1,'']]],
   ['wxpathlist',['wxPathList',['../classwx_path_list.html',1,'']]],
+  ['wxpcxhandler',['wxPCXHandler',['../classwx_p_c_x_handler.html',1,'']]],
   ['wxpen',['wxPen',['../classwx_pen.html',1,'']]],
+  ['wxpeninfo',['wxPenInfo',['../classwx_pen_info.html',1,'']]],
   ['wxpenlist',['wxPenList',['../classwx_pen_list.html',1,'']]],
   ['wxpersistencemanager',['wxPersistenceManager',['../classwx_persistence_manager.html',1,'']]],
   ['wxpersistentbookctrl',['wxPersistentBookCtrl',['../classwx_persistent_book_ctrl.html',1,'']]],
+  ['wxpersistentdataviewctrl',['wxPersistentDataViewCtrl',['../classwx_persistent_data_view_ctrl.html',1,'']]],
   ['wxpersistentobject',['wxPersistentObject',['../classwx_persistent_object.html',1,'']]],
   ['wxpersistenttlw',['wxPersistentTLW',['../classwx_persistent_t_l_w.html',1,'']]],
   ['wxpersistenttreebookctrl',['wxPersistentTreeBookCtrl',['../classwx_persistent_tree_book_ctrl.html',1,'']]],
   ['wxpersistentwindow',['wxPersistentWindow',['../classwx_persistent_window.html',1,'']]],
   ['wxpersistentwindow_3c_20wxbookctrlbase_20_3e',['wxPersistentWindow&lt; wxBookCtrlBase &gt;',['../classwx_persistent_window.html',1,'']]],
+  ['wxpersistentwindow_3c_20wxdataviewctrl_20_3e',['wxPersistentWindow&lt; wxDataViewCtrl &gt;',['../classwx_persistent_window.html',1,'']]],
   ['wxpersistentwindow_3c_20wxtoplevelwindow_20_3e',['wxPersistentWindow&lt; wxTopLevelWindow &gt;',['../classwx_persistent_window.html',1,'']]],
+  ['wxpgarrayeditordialog',['wxPGArrayEditorDialog',['../classwx_p_g_array_editor_dialog.html',1,'']]],
+  ['wxpgarraystringeditordialog',['wxPGArrayStringEditorDialog',['../classwx_p_g_array_string_editor_dialog.html',1,'']]],
+  ['wxpgattributestorage',['wxPGAttributeStorage',['../classwx_p_g_attribute_storage.html',1,'']]],
   ['wxpgcell',['wxPGCell',['../classwx_p_g_cell.html',1,'']]],
+  ['wxpgcelldata',['wxPGCellData',['../classwx_p_g_cell_data.html',1,'']]],
+  ['wxpgcellrenderer',['wxPGCellRenderer',['../classwx_p_g_cell_renderer.html',1,'']]],
+  ['wxpgcheckboxeditor',['wxPGCheckBoxEditor',['../classwx_p_g_check_box_editor.html',1,'']]],
+  ['wxpgchoiceandbuttoneditor',['wxPGChoiceAndButtonEditor',['../classwx_p_g_choice_and_button_editor.html',1,'']]],
+  ['wxpgchoiceeditor',['wxPGChoiceEditor',['../classwx_p_g_choice_editor.html',1,'']]],
+  ['wxpgchoiceentry',['wxPGChoiceEntry',['../classwx_p_g_choice_entry.html',1,'']]],
   ['wxpgchoices',['wxPGChoices',['../classwx_p_g_choices.html',1,'']]],
+  ['wxpgchoicesdata',['wxPGChoicesData',['../classwx_p_g_choices_data.html',1,'']]],
+  ['wxpgcomboboxeditor',['wxPGComboBoxEditor',['../classwx_p_g_combo_box_editor.html',1,'']]],
+  ['wxpgdefaultrenderer',['wxPGDefaultRenderer',['../classwx_p_g_default_renderer.html',1,'']]],
   ['wxpgeditor',['wxPGEditor',['../classwx_p_g_editor.html',1,'']]],
+  ['wxpgeditordialogadapter',['wxPGEditorDialogAdapter',['../classwx_p_g_editor_dialog_adapter.html',1,'']]],
+  ['wxpgfiledialogadapter',['wxPGFileDialogAdapter',['../classwx_p_g_file_dialog_adapter.html',1,'']]],
+  ['wxpgindialogvalidator',['wxPGInDialogValidator',['../classwx_p_g_in_dialog_validator.html',1,'']]],
+  ['wxpglongstringdialogadapter',['wxPGLongStringDialogAdapter',['../classwx_p_g_long_string_dialog_adapter.html',1,'']]],
   ['wxpgmultibutton',['wxPGMultiButton',['../classwx_p_g_multi_button.html',1,'']]],
+  ['wxpgpaintdata',['wxPGPaintData',['../structwx_p_g_paint_data.html',1,'']]],
+  ['wxpgpropargcls',['wxPGPropArgCls',['../classwx_p_g_prop_arg_cls.html',1,'']]],
   ['wxpgproperty',['wxPGProperty',['../classwx_p_g_property.html',1,'']]],
+  ['wxpgrootproperty',['wxPGRootProperty',['../classwx_p_g_root_property.html',1,'']]],
+  ['wxpgspinctrleditor',['wxPGSpinCtrlEditor',['../classwx_p_g_spin_ctrl_editor.html',1,'']]],
+  ['wxpgtextctrlandbuttoneditor',['wxPGTextCtrlAndButtonEditor',['../classwx_p_g_text_ctrl_and_button_editor.html',1,'']]],
+  ['wxpgtextctrleditor',['wxPGTextCtrlEditor',['../classwx_p_g_text_ctrl_editor.html',1,'']]],
   ['wxpgvalidationinfo',['wxPGValidationInfo',['../classwx_p_g_validation_info.html',1,'']]],
   ['wxpgviterator',['wxPGVIterator',['../classwx_p_g_v_iterator.html',1,'']]],
+  ['wxpgwindowlist',['wxPGWindowList',['../classwx_p_g_window_list.html',1,'']]],
   ['wxpickerbase',['wxPickerBase',['../classwx_picker_base.html',1,'']]],
   ['wxpixeldata',['wxPixelData',['../classwx_pixel_data.html',1,'']]],
   ['wxplatforminfo',['wxPlatformInfo',['../classwx_platform_info.html',1,'']]],
+  ['wxpnghandler',['wxPNGHandler',['../classwx_p_n_g_handler.html',1,'']]],
+  ['wxpnmhandler',['wxPNMHandler',['../classwx_p_n_m_handler.html',1,'']]],
   ['wxpoint',['wxPoint',['../classwx_point.html',1,'']]],
   ['wxpoint2ddouble',['wxPoint2DDouble',['../classwx_point2_d_double.html',1,'']]],
   ['wxpoint2dint',['wxPoint2DInt',['../classwx_point2_d_int.html',1,'']]],
@@ -548,6 +613,7 @@ var searchData=
   ['wxpowerresourceblocker',['wxPowerResourceBlocker',['../classwx_power_resource_blocker.html',1,'']]],
   ['wxpreferenceseditor',['wxPreferencesEditor',['../classwx_preferences_editor.html',1,'']]],
   ['wxpreferencespage',['wxPreferencesPage',['../classwx_preferences_page.html',1,'']]],
+  ['wxpressandtapevent',['wxPressAndTapEvent',['../classwx_press_and_tap_event.html',1,'']]],
   ['wxpreviewcanvas',['wxPreviewCanvas',['../classwx_preview_canvas.html',1,'']]],
   ['wxpreviewcontrolbar',['wxPreviewControlBar',['../classwx_preview_control_bar.html',1,'']]],
   ['wxpreviewframe',['wxPreviewFrame',['../classwx_preview_frame.html',1,'']]],
@@ -564,13 +630,18 @@ var searchData=
   ['wxprogressdialog',['wxProgressDialog',['../classwx_progress_dialog.html',1,'']]],
   ['wxpropagateonce',['wxPropagateOnce',['../classwx_propagate_once.html',1,'']]],
   ['wxpropagationdisabler',['wxPropagationDisabler',['../classwx_propagation_disabler.html',1,'']]],
+  ['wxpropertycategory',['wxPropertyCategory',['../classwx_property_category.html',1,'']]],
   ['wxpropertygrid',['wxPropertyGrid',['../classwx_property_grid.html',1,'']]],
+  ['wxpropertygridconstiterator',['wxPropertyGridConstIterator',['../classwx_property_grid_const_iterator.html',1,'']]],
   ['wxpropertygridevent',['wxPropertyGridEvent',['../classwx_property_grid_event.html',1,'']]],
-  ['wxpropertygridhittestresult',['wxPropertyGridHitTestResult',['../structwx_property_grid_hit_test_result.html',1,'']]],
+  ['wxpropertygridhittestresult',['wxPropertyGridHitTestResult',['../classwx_property_grid_hit_test_result.html',1,'']]],
   ['wxpropertygridinterface',['wxPropertyGridInterface',['../classwx_property_grid_interface.html',1,'']]],
   ['wxpropertygriditerator',['wxPropertyGridIterator',['../classwx_property_grid_iterator.html',1,'']]],
+  ['wxpropertygriditeratorbase',['wxPropertyGridIteratorBase',['../classwx_property_grid_iterator_base.html',1,'']]],
   ['wxpropertygridmanager',['wxPropertyGridManager',['../classwx_property_grid_manager.html',1,'']]],
   ['wxpropertygridpage',['wxPropertyGridPage',['../classwx_property_grid_page.html',1,'']]],
+  ['wxpropertygridpagestate',['wxPropertyGridPageState',['../classwx_property_grid_page_state.html',1,'']]],
+  ['wxpropertygridpopulator',['wxPropertyGridPopulator',['../classwx_property_grid_populator.html',1,'']]],
   ['wxpropertysheetdialog',['wxPropertySheetDialog',['../classwx_property_sheet_dialog.html',1,'']]],
   ['wxprotocol',['wxProtocol',['../classwx_protocol.html',1,'']]],
   ['wxprotocollog',['wxProtocolLog',['../classwx_protocol_log.html',1,'']]],
@@ -598,6 +669,7 @@ var searchData=
   ['wxrendererversion',['wxRendererVersion',['../structwx_renderer_version.html',1,'']]],
   ['wxresourcetranslationsloader',['wxResourceTranslationsLoader',['../classwx_resource_translations_loader.html',1,'']]],
   ['wxribbonartprovider',['wxRibbonArtProvider',['../classwx_ribbon_art_provider.html',1,'']]],
+  ['wxribbonauiartprovider',['wxRibbonAUIArtProvider',['../classwx_ribbon_a_u_i_art_provider.html',1,'']]],
   ['wxribbonbar',['wxRibbonBar',['../classwx_ribbon_bar.html',1,'']]],
   ['wxribbonbarevent',['wxRibbonBarEvent',['../classwx_ribbon_bar_event.html',1,'']]],
   ['wxribbonbuttonbar',['wxRibbonButtonBar',['../classwx_ribbon_button_bar.html',1,'']]],
@@ -605,10 +677,13 @@ var searchData=
   ['wxribboncontrol',['wxRibbonControl',['../classwx_ribbon_control.html',1,'']]],
   ['wxribbongallery',['wxRibbonGallery',['../classwx_ribbon_gallery.html',1,'']]],
   ['wxribbongalleryevent',['wxRibbonGalleryEvent',['../classwx_ribbon_gallery_event.html',1,'']]],
+  ['wxribbonmswartprovider',['wxRibbonMSWArtProvider',['../classwx_ribbon_m_s_w_art_provider.html',1,'']]],
   ['wxribbonpage',['wxRibbonPage',['../classwx_ribbon_page.html',1,'']]],
+  ['wxribbonpagetabinfo',['wxRibbonPageTabInfo',['../classwx_ribbon_page_tab_info.html',1,'']]],
   ['wxribbonpanel',['wxRibbonPanel',['../classwx_ribbon_panel.html',1,'']]],
   ['wxribbonpanelevent',['wxRibbonPanelEvent',['../classwx_ribbon_panel_event.html',1,'']]],
   ['wxribbontoolbar',['wxRibbonToolBar',['../classwx_ribbon_tool_bar.html',1,'']]],
+  ['wxribbontoolbarevent',['wxRibbonToolBarEvent',['../classwx_ribbon_tool_bar_event.html',1,'']]],
   ['wxrichmessagedialog',['wxRichMessageDialog',['../classwx_rich_message_dialog.html',1,'']]],
   ['wxrichtextaction',['wxRichTextAction',['../classwx_rich_text_action.html',1,'']]],
   ['wxrichtextattr',['wxRichTextAttr',['../classwx_rich_text_attr.html',1,'']]],
@@ -661,6 +736,7 @@ var searchData=
   ['wxrichtexttableblock',['wxRichTextTableBlock',['../classwx_rich_text_table_block.html',1,'']]],
   ['wxrichtextxmlhandler',['wxRichTextXMLHandler',['../classwx_rich_text_x_m_l_handler.html',1,'']]],
   ['wxrichtooltip',['wxRichToolTip',['../classwx_rich_tool_tip.html',1,'']]],
+  ['wxrotategestureevent',['wxRotateGestureEvent',['../classwx_rotate_gesture_event.html',1,'']]],
   ['wxsashevent',['wxSashEvent',['../classwx_sash_event.html',1,'']]],
   ['wxsashlayoutwindow',['wxSashLayoutWindow',['../classwx_sash_layout_window.html',1,'']]],
   ['wxsashwindow',['wxSashWindow',['../classwx_sash_window.html',1,'']]],
@@ -678,6 +754,8 @@ var searchData=
   ['wxscrollevent',['wxScrollEvent',['../classwx_scroll_event.html',1,'']]],
   ['wxscrollwinevent',['wxScrollWinEvent',['../classwx_scroll_win_event.html',1,'']]],
   ['wxsearchctrl',['wxSearchCtrl',['../classwx_search_ctrl.html',1,'']]],
+  ['wxsecretstore',['wxSecretStore',['../classwx_secret_store.html',1,'']]],
+  ['wxsecretvalue',['wxSecretValue',['../classwx_secret_value.html',1,'']]],
   ['wxsemaphore',['wxSemaphore',['../classwx_semaphore.html',1,'']]],
   ['wxserver',['wxServer',['../classwx_server.html',1,'']]],
   ['wxsetcursorevent',['wxSetCursorEvent',['../classwx_set_cursor_event.html',1,'']]],
@@ -741,6 +819,7 @@ var searchData=
   ['wxstringclientdata',['wxStringClientData',['../classwx_string_client_data.html',1,'']]],
   ['wxstringinputstream',['wxStringInputStream',['../classwx_string_input_stream.html',1,'']]],
   ['wxstringoutputstream',['wxStringOutputStream',['../classwx_string_output_stream.html',1,'']]],
+  ['wxstringproperty',['wxStringProperty',['../classwx_string_property.html',1,'']]],
   ['wxstringtokenizer',['wxStringTokenizer',['../classwx_string_tokenizer.html',1,'']]],
   ['wxstyledtextctrl',['wxStyledTextCtrl',['../classwx_styled_text_ctrl.html',1,'']]],
   ['wxstyledtextevent',['wxStyledTextEvent',['../classwx_styled_text_event.html',1,'']]],
@@ -750,6 +829,7 @@ var searchData=
   ['wxsvgfiledc',['wxSVGFileDC',['../classwx_s_v_g_file_d_c.html',1,'']]],
   ['wxsymbolpickerdialog',['wxSymbolPickerDialog',['../classwx_symbol_picker_dialog.html',1,'']]],
   ['wxsyscolourchangedevent',['wxSysColourChangedEvent',['../classwx_sys_colour_changed_event.html',1,'']]],
+  ['wxsystemcolourproperty',['wxSystemColourProperty',['../classwx_system_colour_property.html',1,'']]],
   ['wxsystemoptions',['wxSystemOptions',['../classwx_system_options.html',1,'']]],
   ['wxsystemsettings',['wxSystemSettings',['../classwx_system_settings.html',1,'']]],
   ['wxsystemthemedcontrol',['wxSystemThemedControl',['../classwx_system_themed_control.html',1,'']]],
@@ -790,10 +870,12 @@ var searchData=
   ['wxtexturlevent',['wxTextUrlEvent',['../classwx_text_url_event.html',1,'']]],
   ['wxtextvalidator',['wxTextValidator',['../classwx_text_validator.html',1,'']]],
   ['wxtextwrapper',['wxTextWrapper',['../classwx_text_wrapper.html',1,'']]],
+  ['wxtgahandler',['wxTGAHandler',['../classwx_t_g_a_handler.html',1,'']]],
   ['wxthread',['wxThread',['../classwx_thread.html',1,'']]],
   ['wxthreadevent',['wxThreadEvent',['../classwx_thread_event.html',1,'']]],
   ['wxthreadhelper',['wxThreadHelper',['../classwx_thread_helper.html',1,'']]],
   ['wxthumbbarbutton',['wxThumbBarButton',['../classwx_thumb_bar_button.html',1,'']]],
+  ['wxtiffhandler',['wxTIFFHandler',['../classwx_t_i_f_f_handler.html',1,'']]],
   ['wxtimepickerctrl',['wxTimePickerCtrl',['../classwx_time_picker_ctrl.html',1,'']]],
   ['wxtimer',['wxTimer',['../classwx_timer.html',1,'']]],
   ['wxtimerevent',['wxTimerEvent',['../classwx_timer_event.html',1,'']]],
@@ -820,7 +902,9 @@ var searchData=
   ['wxtreelistevent',['wxTreeListEvent',['../classwx_tree_list_event.html',1,'']]],
   ['wxtreelistitem',['wxTreeListItem',['../classwx_tree_list_item.html',1,'']]],
   ['wxtreelistitemcomparator',['wxTreeListItemComparator',['../classwx_tree_list_item_comparator.html',1,'']]],
+  ['wxtwofingertapevent',['wxTwoFingerTapEvent',['../classwx_two_finger_tap_event.html',1,'']]],
   ['wxuiactionsimulator',['wxUIActionSimulator',['../classwx_u_i_action_simulator.html',1,'']]],
+  ['wxuintproperty',['wxUIntProperty',['../classwx_u_int_property.html',1,'']]],
   ['wxulonglong',['wxULongLong',['../classwx_u_long_long.html',1,'']]],
   ['wxunichar',['wxUniChar',['../classwx_uni_char.html',1,'']]],
   ['wxunicharref',['wxUniCharRef',['../classwx_uni_char_ref.html',1,'']]],
@@ -882,11 +966,13 @@ var searchData=
   ['wxxmlnode',['wxXmlNode',['../classwx_xml_node.html',1,'']]],
   ['wxxmlresource',['wxXmlResource',['../classwx_xml_resource.html',1,'']]],
   ['wxxmlresourcehandler',['wxXmlResourceHandler',['../classwx_xml_resource_handler.html',1,'']]],
+  ['wxxpmhandler',['wxXPMHandler',['../classwx_x_p_m_handler.html',1,'']]],
   ['wxzipclassfactory',['wxZipClassFactory',['../classwx_zip_class_factory.html',1,'']]],
   ['wxzipentry',['wxZipEntry',['../classwx_zip_entry.html',1,'']]],
   ['wxzipinputstream',['wxZipInputStream',['../classwx_zip_input_stream.html',1,'']]],
   ['wxzipnotifier',['wxZipNotifier',['../classwx_zip_notifier.html',1,'']]],
   ['wxzipoutputstream',['wxZipOutputStream',['../classwx_zip_output_stream.html',1,'']]],
   ['wxzlibinputstream',['wxZlibInputStream',['../classwx_zlib_input_stream.html',1,'']]],
-  ['wxzliboutputstream',['wxZlibOutputStream',['../classwx_zlib_output_stream.html',1,'']]]
+  ['wxzliboutputstream',['wxZlibOutputStream',['../classwx_zlib_output_stream.html',1,'']]],
+  ['wxzoomgestureevent',['wxZoomGestureEvent',['../classwx_zoom_gesture_event.html',1,'']]]
 ];
