@@ -2,6 +2,8 @@ var searchData=
 [
   ['calendar',['Calendar',['../classwx_date_time.html#ab2c1717e9dff5256cc01f917a5b7f70c',1,'wxDateTime']]],
   ['cellspan',['CellSpan',['../classwx_grid.html#a601788de28c3c493f93c533eff7af1fd',1,'wxGrid']]],
+  ['configfileconv',['ConfigFileConv',['../classwx_standard_paths.html#a94cd66ecb1676ef8a0f5ed29ecb9615e',1,'wxStandardPaths']]],
   ['context',['Context',['../classwx_debug_report.html#a10c883cbb07392fffd65d031c55aa23b',1,'wxDebugReport']]],
+  ['conversionflags',['ConversionFlags',['../classwx_array_string_property.html#a26a4a79a90e547ec23ceb6e79c2fbafa',1,'wxArrayStringProperty']]],
   ['country',['Country',['../classwx_date_time.html#abdd3b3e656f92a4923c3ddf2026ed126',1,'wxDateTime']]]
 ];
