@@ -3,7 +3,7 @@ var searchData=
   ['char_5ftype',['char_type',['../classwx_string.html#a6d7f9c6d210daec80bb59763e3016516',1,'wxString']]],
   ['chartype',['CharType',['../classwx_scoped_char_type_buffer.html#af80c4ff48b92f8e01b6167ff0468e213',1,'wxScopedCharTypeBuffer']]],
   ['comparefunction',['CompareFunction',['../classwx_array_string.html#ab3765f8d31f415ef480c3224c390eda3',1,'wxArrayString']]],
-  ['const_5fiterator',['const_iterator',['../classwx_vector_3_01_t_01_4.html#a82f52b139a4601c6e2fa40541d586161',1,'wxVector&lt; T &gt;']]],
+  ['const_5fiterator',['const_iterator',['../classwx_p_g_attribute_storage.html#a5bd8dc046c16bc9ecf95cd5b43882121',1,'wxPGAttributeStorage::const_iterator()'],['../classwx_vector_3_01_t_01_4.html#a82f52b139a4601c6e2fa40541d586161',1,'wxVector&lt; T &gt;::const_iterator()']]],
   ['const_5fpointer',['const_pointer',['../classwx_string.html#a9c8b22db8c1446c53f1728c261d2d65b',1,'wxString']]],
   ['const_5freference',['const_reference',['../classwx_string.html#afd79e86aee78b7aab5e82483ab8d7a57',1,'wxString']]],
   ['container_5ftype',['container_type',['../classwx_stack_3_01_t_01_4.html#a2a4f590c8d1c24164868080347d4822d',1,'wxStack&lt; T &gt;']]]
