@@ -32,8 +32,9 @@ var searchData=
   ['wxintptr',['wxIntPtr',['../defs_8h.html#adc7fafddfefae454021d2e0660c96487',1,'defs.h']]],
   ['wxloglevel',['wxLogLevel',['../interface_2wx_2log_8h.html#ae0480cde4ec31e0f2e502e6e3082e74c',1,'log.h']]],
   ['wxobjectrefdata',['wxObjectRefData',['../object_8h.html#ab7149af7eced89712baaf20432d66e19',1,'object.h']]],
-  ['wxpgsortcallback',['wxPGSortCallback',['../interface_2wx_2propgrid_2propgrid_8h.html#add392b8d6550141475e3efb953b0a20f',1,'propgrid.h']]],
-  ['wxpgvfbflags',['wxPGVFBFlags',['../interface_2wx_2propgrid_2propgrid_8h.html#ae6021bf370bb7766e513f49649dee232',1,'propgrid.h']]],
+  ['wxpgcachedstring',['wxPGCachedString',['../propgriddefs_8h.html#afe257745b4d138d5d3414baeb2260be1',1,'propgriddefs.h']]],
+  ['wxpgproparg',['wxPGPropArg',['../propgridiface_8h.html#a3f566131b8cbb5f0e282b3db4f5c501c',1,'propgridiface.h']]],
+  ['wxpgsortcallback',['wxPGSortCallback',['../interface_2wx_2propgrid_2propgrid_8h.html#add392b8d6550141475e3efb953b0a20f',1,'wxPGSortCallback():&#160;propgrid.h'],['../propgriddefs_8h.html#add392b8d6550141475e3efb953b0a20f',1,'wxPGSortCallback():&#160;propgriddefs.h']]],
   ['wxprintquality',['wxPrintQuality',['../defs_8h.html#aa032c3ba9e7b8f969fcf14136fde8b16',1,'defs.h']]],
   ['wxschar',['wxSChar',['../group__group__funcmacro__string.html#ga8e3a080c0791e25bc023ae714000b857',1,'chartype.h']]],
   ['wxscopedcharbuffer',['wxScopedCharBuffer',['../buffer_8h.html#a76c552ab140910c2abd59a2a6a69a724',1,'buffer.h']]],
