@@ -1,6 +1,8 @@
 var searchData=
 [
+  ['icon',['icon',['../classwx_aui_pane_info.html#a9a0522b3a93f51ca8950d8ab34bba2b7',1,'wxAuiPaneInfo']]],
   ['id',['id',['../classwx_aui_tab_container_button.html#af04db78685d45b7181e79ab260150012',1,'wxAuiTabContainerButton::id()'],['../structwx_html_help_data_item.html#af9842cf2c0d0a73765bc5d4f4bb25280',1,'wxHtmlHelpDataItem::id()'],['../structwx_linux_distribution_info.html#a2369fa0c23c969ff02906be4f56341ca',1,'wxLinuxDistributionInfo::Id()']]],
+  ['ideal_5fwidth',['ideal_width',['../classwx_ribbon_page_tab_info.html#a2c2e1968cfbb684c4ea487fad3e5cc10',1,'wxRibbonPageTabInfo']]],
   ['internalleading',['internalLeading',['../structwx_font_metrics.html#a118ea02d51fa606b315e33fca19fca9f',1,'wxFontMetrics']]],
   ['ishotsensitive',['isHotSensitive',['../structwx_splitter_render_params.html#a908fbc631c9c14219b6e813e1dca8e50',1,'wxSplitterRenderParams']]]
 ];
